@@ -15,8 +15,8 @@ keyness_barplot <- function(tab, range = NULL, title = "", title_color = "firebr
     geom_col(aes(fill = sign), color = "white", width = 1) +
     geom_text(y = stat_max / 15, aes(label = stats::reorder(feature, !!stat_col_tidy)), hjust = 0, size = text_size / 2.5) +
     coord_flip() +
-    scale_fill_manual("", guide = FALSE,
-      values = c("positive" = "#a1d8ff", "negative" = "#ff7d7e")) +
+    scale_fill_manual("", values = c("positive" = "#a1d8ff", "negative" = "#ff7d7e")) +
+    guides(fill = "none") +
     labs(title = title, x = "") +
     theme_minimal() +
     theme(
@@ -29,21 +29,21 @@ keyness_barplot <- function(tab, range = NULL, title = "", title_color = "firebr
         colour = "transparent"))
   ## Fix x limits if necessary and remove horizontal axis values
   if (!is.null(range)) {
-    g <- g + scale_y_continuous(stat_col, limits = range, breaks = NULL)
+    g <- g + ggplot2::scale_y_continuous(stat_col, limits = range, breaks = NULL)
   } else {
-    g <- g + scale_y_continuous(stat_col, breaks = NULL)
+    g <- g + ggplot2::scale_y_continuous(stat_col, breaks = NULL)
   }
   ## Adjust vertical scale if necessary
   if (nrow(tab) < n_terms) {
     limits <- levels(stats::reorder(tab$feature, tab[[stat_col]]))
     limits <- c(rep("", n_terms - length(limits)), limits)
-    g <- g + scale_x_discrete(limits = limits, breaks = NULL)
+    g <- g + ggplot2::scale_x_discrete(limits = limits, breaks = NULL)
   } else {
-    g <- g + scale_x_discrete(breaks = NULL)
+    g <- g + ggplot2::scale_x_discrete(breaks = NULL)
   }
 
   ## Align title element to the left to center it with hjust
-  g <- ggplotGrob(g)
+  g <- ggplot2::ggplotGrob(g)
   g$layout$l[g$layout$name == "title"] <- 1
   g
 }
@@ -74,13 +74,13 @@ keyness_worcloud <- function(tab, range = NULL, title = "", title_color = "fireb
         colour = "transparent"))
   ## Fix x limits if necessary and remove horizontal axis values
   if (!is.null(range)) {
-    g <- g + scale_size_area(limits = range, max_size = max_size)
+    g <- g + ggplot2::scale_size_area(limits = range, max_size = max_size)
   } else {
-    g <- g + scale_size_area(max_size = max_size)
+    g <- g + ggplot2::scale_size_area(max_size = max_size)
   }
 
   ## Align title element to the left to center it with hjust
-  g <- ggplotGrob(g)
+  g <- ggplot2::ggplotGrob(g)
   g$layout$l[g$layout$name == "title"] <- 1
   g
 }
@@ -91,18 +91,15 @@ keyness_worcloud <- function(tab, range = NULL, title = "", title_color = "fireb
 
 groups_colors <- function(k, i = NULL) {
   ## Groups colors
-  if (k <= 5) {
-    col <- RColorBrewer::brewer.pal(9, "Set1")[1:k]
-  } else if (k <= 12) {
-    col <- RColorBrewer::brewer.pal(12, "Paired")[1:k]
-  } else {
-    col <- rep("firebrick3", k)
-  }
+  col <- grDevices::palette.colors(n = 10, palette = "Tableau 10")
+  col <- rep_len(col, k)
 
   if (!is.null(i)) {
     return(col[i])
+  } else {
+    return(col)
   }
-  col
+
 }
 
 
@@ -117,7 +114,13 @@ keyness_plots <- function(tabs, groups, type = "bar",
   k <- length(tabs)
 
   purrr::map(1:k, function(i) {
-    title <- paste0("n = ", clust_n[i], "\n", clust_prop[i], "%")
+    if (k <= 6) {
+      title <- paste0("Cluster ", i, "\nn = ", clust_n[i], " (", clust_prop[i], "%)")
+    } else if (k <= 8) {
+      title <- paste0("Cluster ", i, "\nn = ", clust_n[i])
+    } else {
+      title <- paste0("Cl. ", i, "\nn = ", clust_n[i])
+    }
     if (type == "bar") {
       if (is.null(text_size)) text_size <- 10
       keyness_barplot(tabs[[i]], range, title = title, title_color = groups_colors(k, i),
@@ -153,13 +156,15 @@ keyness_plots <- function(tabs, groups, type = "bar",
 #' @export
 #' @examples
 #' \donttest{
-#' library(quanteda)
+#' require(quanteda)
 #' corpus <- data_corpus_inaugural
 #' corpus <- head(corpus, n = 10)
 #' corpus <- split_segments(corpus)
-#' dtm <- dfm(corpus, remove = stopwords("en"), tolower = TRUE, remove_punct = TRUE)
-#' dtm <- dfm_trim(dtm, min_termfreq = 3)
-#' res <- rainette(dtm, k = 3)
+#' tok <- tokens(corpus, remove_punct = TRUE)
+#' tok <- tokens_remove(tok, stopwords("en"))
+#' dtm <- dfm(tok, tolower = TRUE)
+#' dtm <- dfm_trim(dtm, min_docfreq = 3)
+#' res <- rainette(dtm, k = 3, min_segment_size = 15)
 #' rainette_plot(res, dtm)
 #' }
 #'
@@ -168,8 +173,9 @@ keyness_plots <- function(tabs, groups, type = "bar",
 
 rainette_plot <- function(res, dtm, k = NULL,
                           type = c("bar", "cloud"), n_terms = 15,
-                          free_scales = FALSE, measure = c("chi2", "lr"),
-                          show_negative = TRUE,
+                          free_scales = FALSE, 
+                          measure = c("chi2", "lr", "frequency", "docprop"),
+                          show_negative = FALSE,
                           text_size = NULL) {
 
   type <- match.arg(type)
@@ -188,31 +194,35 @@ rainette_plot <- function(res, dtm, k = NULL,
     k <- max_k
   } else {
     if (k < 2 || k > max_k) stop("k must be between 2 and ", max_k)
-    groups <- cutree_rainette(res, k)
+    groups <- rainette::cutree_rainette(res, k)
   }
 
   ## Keyness statistics
-  tabs <- rainette_stats(groups, dtm, measure, n_terms, show_negative)
+  tabs <- rainette::rainette_stats(groups, dtm, measure, n_terms, show_negative)
 
   ## Number of NA
   na_n <- sum(is.na(groups))
   na_prop <- round(na_n / length(groups) * 100, 1)
 
   ## Min and max statistics to fix x axis in terms plots
-  range <- NULL
-  if (!free_scales) {
-    max_stat <- max(purrr::map_dbl(tabs, ~ max(.x %>% pull(!!stat_col))))
-    range <- c(0, max_stat)
+  if (measure == "docprop") {
+    range <- c(0, 1)
+  } else {
+    range <- NULL
+    if (!free_scales) {
+      max_stat <- max(purrr::map_dbl(tabs, ~ max(.x %>% pull(!!stat_col))))
+      range <- c(0, max_stat)
+    }
   }
   ## Graph layout
-  lay <- matrix(c(rep(1, k), rep(2:(k+1), 2)), nrow = 3, ncol = k, byrow = TRUE)
+  lay <- matrix(c(rep(1, k), rep(2:(k + 1), 2)), nrow = 3, ncol = k, byrow = TRUE)
   plots <- list()
 
   ## Dendrogram
   dend <- stats::as.dendrogram(res)
   max_k <- max(res$group, na.rm = TRUE)
   ## Cut the dendrogram if necessary
-  if( k < max_k) {
+  if(k < max_k) {
     dend <- cut(dend, res$height[max_k - k])$upper
     ## Double conversion to "balance" the dendrogram
     dend <- stats::as.dendrogram(stats::as.hclust(dend))
@@ -225,12 +235,12 @@ rainette_plot <- function(res, dtm, k = NULL,
     dendextend::set("branches_lwd", 0.4)
   ## Generate plot
   dend <- dendextend::as.ggdend(dend)
-  margin <- ifelse(k>=7, 0, 0.175 - k * 0.025)
+  margin <- ifelse(k >= 7, 0, 0.175 - k * 0.025)
   title_size <- ifelse(is.null(text_size), 10, text_size)
   g <- ggplot(dend, nodes = FALSE) +
     scale_y_continuous(breaks = NULL) +
     ggtitle(paste0("NA : ", na_n, " (", na_prop, "%)")) +
-    theme(plot.margin = grid::unit(c(0.05,margin,0,margin), "npc"),
+    theme(plot.margin = grid::unit(c(0.05, margin, 0, margin), "npc"),
           plot.title = element_text(hjust = 0.5, size = title_size))
   plots[[1]] <- g
 
@@ -275,8 +285,8 @@ rainette_plot <- function(res, dtm, k = NULL,
 rainette2_plot <- function(res, dtm, k = NULL, criterion = c("chi2", "n"),
   complete_groups = FALSE,
   type = c("bar", "cloud"), n_terms = 15,
-  free_scales = FALSE, measure = c("chi2", "lr"),
-  show_negative = TRUE,
+  free_scales = FALSE, measure = c("chi2", "lr", "frequency", "docprop"),
+  show_negative = FALSE,
   text_size = 10) {
 
   type <- match.arg(type)
@@ -288,19 +298,23 @@ rainette2_plot <- function(res, dtm, k = NULL, criterion = c("chi2", "n"),
   max_k <- max(res$k, na.rm = TRUE)
 
   if (k < 2 || k > max_k) stop("k must be between 2 and ", max_k)
-  groups <- cutree_rainette2(res, k, criterion)
+  groups <- rainette::cutree_rainette2(res, k, criterion)
   if (complete_groups) {
-    groups <- rainette2_complete_groups(dtm, groups)
+    groups <- rainette::rainette2_complete_groups(dtm, groups)
   }
 
   ## Keyness statistics
-  tabs <- rainette_stats(groups, dtm, measure, n_terms, show_negative)
+  tabs <- rainette::rainette_stats(groups, dtm, measure, n_terms, show_negative)
 
   ## Min and max statistics to fix x axis in terms plots
-  range <- NULL
-  if (!free_scales) {
-    max_stat <- max(purrr::map_dbl(tabs, ~ max(.x %>% pull(!!stat_col))))
-    range <- c(0, max_stat)
+   if (measure == "docprop") {
+    range <- c(0, 1)
+  } else {
+    range <- NULL
+    if (!free_scales) {
+      max_stat <- max(purrr::map_dbl(tabs, ~ max(.x %>% pull(!!stat_col))))
+      range <- c(0, max_stat)
+    }
   }
   ## Graph layout
   if (k <= 5) {
@@ -321,7 +335,8 @@ rainette2_plot <- function(res, dtm, k = NULL, criterion = c("chi2", "n"),
   colnames(freq) <- c("Group", "n")
   g <- ggplot(freq) +
     geom_col(aes(x = Group, y = n, fill = Group)) +
-    scale_fill_manual(guide = FALSE, values = c(groups_colors(k)), na.value = "grey20") +
+    scale_fill_manual(values = c(groups_colors(k)), na.value = "grey20") +
+    guides(fill = "none") +
     ggtitle(title) +
     theme(
       plot.title = element_text(size = 10, face = "bold", hjust = 0.5),
